# Meeting Script

## Prepared Questions

- What is your feedback on the improved summary output and token estimation feature?

- What do you suggest for seeing contributors (who made the changes) in the summary?

- How do you suggest to make the CLI more friendly? (Impelementing date ranges)

- How valuable would intent-based summaries be (e.g., only new features, only breaking changes, only documentation)?

- Is there anything we should focus on to improve previous weeks’ grades?

## Taken Down Notes

Summary improvement: Contributor should be mentioned directly in the summary

Specify range of dates instead of commit hashes and then we get the commits in the range for example (between date-1 and date-2)

Mainly for next week: make the CLI more friendly (using a range of dates instead of copying the hashes).

For more points: define use cases for our tool to create the investor report about another team
